==> hibernate-core-6.1.7.Final-sources.jar: org/hibernate/boot/jaxb/mapping/JaxbCascadeType.java <==

package org.hibernate.boot.jaxb.mapping;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 *                 See `@jakarta.persistence.CascadeType`
 *                 See `@org.hibernate.annotations.Cascade`
 *             
 * 
 * <p>Java class for cascade-type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="cascade-type"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="cascade-all" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-persist" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-merge" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-remove" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-refresh" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-detach" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-delete" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-save-update" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-replicate" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *         &lt;element name="cascade-lock" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "cascade-type", namespace = "http://www.hibernate.org/xsd/orm/mapping", propOrder = {
    "cascadeAll",
    "cascadePersist",
    "cascadeMerge",
    "cascadeRemove",
    "cascadeRefresh",
    "cascadeDetach",
    "cascadeDelete",
    "cascadeSaveUpdate",
    "cascadeReplicate",
    "cascadeLock"
})
public class JaxbCascadeType
    implements Serializable
{

    @XmlElement(name = "cascade-all", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeAll;
    @XmlElement(name = "cascade-persist", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadePersist;
    @XmlElement(name = "cascade-merge", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeMerge;
    @XmlElement(name = "cascade-remove", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeRemove;
    @XmlElement(name = "cascade-refresh", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeRefresh;
    @XmlElement(name = "cascade-detach", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeDetach;
    @XmlElement(name = "cascade-delete", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeDelete;
    @XmlElement(name = "cascade-save-update", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeSaveUpdate;
    @XmlElement(name = "cascade-replicate", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeReplicate;
    @XmlElement(name = "cascade-lock", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeLock;

    /**
     * Gets the value of the cascadeAll property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeAll() {
        return cascadeAll;
    }

    /**
     * Sets the value of the cascadeAll property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeAll(JaxbEmptyType value) {
        this.cascadeAll = value;
    }

    /**
     * Gets the value of the cascadePersist property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadePersist() {
        return cascadePersist;
    }

    /**
     * Sets the value of the cascadePersist property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadePersist(JaxbEmptyType value) {
        this.cascadePersist = value;
    }

    /**
     * Gets the value of the cascadeMerge property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeMerge() {
        return cascadeMerge;
    }

    /**
     * Sets the value of the cascadeMerge property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeMerge(JaxbEmptyType value) {
        this.cascadeMerge = value;
    }

    /**
     * Gets the value of the cascadeRemove property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeRemove() {
        return cascadeRemove;
    }

    /**
     * Sets the value of the cascadeRemove property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeRemove(JaxbEmptyType value) {
        this.cascadeRemove = value;
    }

    /**
     * Gets the value of the cascadeRefresh property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeRefresh() {
        return cascadeRefresh;
    }

    /**
     * Sets the value of the cascadeRefresh property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeRefresh(JaxbEmptyType value) {
        this.cascadeRefresh = value;
    }

    /**
     * Gets the value of the cascadeDetach property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeDetach() {
        return cascadeDetach;
    }

    /**
     * Sets the value of the cascadeDetach property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeDetach(JaxbEmptyType value) {
        this.cascadeDetach = value;
    }

    /**
     * Gets the value of the cascadeDelete property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeDelete() {
        return cascadeDelete;
    }

    /**
     * Sets the value of the cascadeDelete property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeDelete(JaxbEmptyType value) {
        this.cascadeDelete = value;
    }

    /**
     * Gets the value of the cascadeSaveUpdate property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeSaveUpdate() {
        return cascadeSaveUpdate;
    }

    /**
     * Sets the value of the cascadeSaveUpdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeSaveUpdate(JaxbEmptyType value) {
        this.cascadeSaveUpdate = value;
    }

    /**
     * Gets the value of the cascadeReplicate property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeReplicate() {
        return cascadeReplicate;
    }

    /**
     * Sets the value of the cascadeReplicate property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeReplicate(JaxbEmptyType value) {
        this.cascadeReplicate = value;
    }

    /**
     * Gets the value of the cascadeLock property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeLock() {
        return cascadeLock;
    }

    /**
     * Sets the value of the cascadeLock property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeLock(JaxbEmptyType value) {
        this.cascadeLock = value;
    }

}

==> hibernate-core-6.2.2.Final-sources.jar: org/hibernate/boot/jaxb/mapping/JaxbCascadeType.java <==

package org.hibernate.boot.jaxb.mapping;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 *                 See `@jakarta.persistence.CascadeType`
 *                 See `@org.hibernate.annotations.Cascade`
 *             
 * 
 * <p>Java class for cascade-type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="cascade-type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="cascade-all" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-persist" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-merge" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-remove" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-refresh" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-detach" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-delete" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-save-update" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-replicate" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *         <element name="cascade-lock" type="{http://www.hibernate.org/xsd/orm/mapping}emptyType" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "cascade-type", namespace = "http://www.hibernate.org/xsd/orm/mapping", propOrder = {
    "cascadeAll",
    "cascadePersist",
    "cascadeMerge",
    "cascadeRemove",
    "cascadeRefresh",
    "cascadeDetach",
    "cascadeDelete",
    "cascadeSaveUpdate",
    "cascadeReplicate",
    "cascadeLock"
})
public class JaxbCascadeType
    implements Serializable
{

    @XmlElement(name = "cascade-all", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeAll;
    @XmlElement(name = "cascade-persist", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadePersist;
    @XmlElement(name = "cascade-merge", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeMerge;
    @XmlElement(name = "cascade-remove", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeRemove;
    @XmlElement(name = "cascade-refresh", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeRefresh;
    @XmlElement(name = "cascade-detach", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeDetach;
    @XmlElement(name = "cascade-delete", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeDelete;
    @XmlElement(name = "cascade-save-update", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeSaveUpdate;
    @XmlElement(name = "cascade-replicate", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeReplicate;
    @XmlElement(name = "cascade-lock", namespace = "http://www.hibernate.org/xsd/orm/mapping")
    protected JaxbEmptyType cascadeLock;

    /**
     * Gets the value of the cascadeAll property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeAll() {
        return cascadeAll;
    }

    /**
     * Sets the value of the cascadeAll property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeAll(JaxbEmptyType value) {
        this.cascadeAll = value;
    }

    /**
     * Gets the value of the cascadePersist property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadePersist() {
        return cascadePersist;
    }

    /**
     * Sets the value of the cascadePersist property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadePersist(JaxbEmptyType value) {
        this.cascadePersist = value;
    }

    /**
     * Gets the value of the cascadeMerge property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeMerge() {
        return cascadeMerge;
    }

    /**
     * Sets the value of the cascadeMerge property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeMerge(JaxbEmptyType value) {
        this.cascadeMerge = value;
    }

    /**
     * Gets the value of the cascadeRemove property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeRemove() {
        return cascadeRemove;
    }

    /**
     * Sets the value of the cascadeRemove property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeRemove(JaxbEmptyType value) {
        this.cascadeRemove = value;
    }

    /**
     * Gets the value of the cascadeRefresh property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeRefresh() {
        return cascadeRefresh;
    }

    /**
     * Sets the value of the cascadeRefresh property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeRefresh(JaxbEmptyType value) {
        this.cascadeRefresh = value;
    }

    /**
     * Gets the value of the cascadeDetach property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeDetach() {
        return cascadeDetach;
    }

    /**
     * Sets the value of the cascadeDetach property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeDetach(JaxbEmptyType value) {
        this.cascadeDetach = value;
    }

    /**
     * Gets the value of the cascadeDelete property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeDelete() {
        return cascadeDelete;
    }

    /**
     * Sets the value of the cascadeDelete property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeDelete(JaxbEmptyType value) {
        this.cascadeDelete = value;
    }

    /**
     * Gets the value of the cascadeSaveUpdate property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeSaveUpdate() {
        return cascadeSaveUpdate;
    }

    /**
     * Sets the value of the cascadeSaveUpdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeSaveUpdate(JaxbEmptyType value) {
        this.cascadeSaveUpdate = value;
    }

    /**
     * Gets the value of the cascadeReplicate property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeReplicate() {
        return cascadeReplicate;
    }

    /**
     * Sets the value of the cascadeReplicate property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeReplicate(JaxbEmptyType value) {
        this.cascadeReplicate = value;
    }

    /**
     * Gets the value of the cascadeLock property.
     * 
     * @return
     *     possible object is
     *     {@link JaxbEmptyType }
     *     
     */
    public JaxbEmptyType getCascadeLock() {
        return cascadeLock;
    }

    /**
     * Sets the value of the cascadeLock property.
     * 
     * @param value
     *     allowed object is
     *     {@link JaxbEmptyType }
     *     
     */
    public void setCascadeLock(JaxbEmptyType value) {
        this.cascadeLock = value;
    }

}
